@@ -6,9 +6,9 @@ Type annotations for rbin service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_rbin.type_defs import CreateRuleRequestRequestTypeDef
+    from mypy_boto3_rbin.type_defs import ResourceTagTypeDef
 
-    data: CreateRuleRequestRequestTypeDef = {...}
+    data: ResourceTagTypeDef = {...}
     ```
 """
 import sys
@@ -27,171 +27,26 @@ else:
 
 
 __all__ = (
-    "CreateRuleRequestRequestTypeDef",
-    "CreateRuleResponseTypeDef",
-    "DeleteRuleRequestRequestTypeDef",
-    "GetRuleRequestRequestTypeDef",
-    "GetRuleResponseTypeDef",
-    "ListRulesRequestListRulesPaginateTypeDef",
-    "ListRulesRequestRequestTypeDef",
-    "ListRulesResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "PaginatorConfigTypeDef",
     "ResourceTagTypeDef",
-    "ResponseMetadataTypeDef",
     "RetentionPeriodTypeDef",
-    "RuleSummaryTypeDef",
-    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
-    "UntagResourceRequestRequestTypeDef",
-    "UpdateRuleRequestRequestTypeDef",
-    "UpdateRuleResponseTypeDef",
-)
-
-_RequiredCreateRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateRuleRequestRequestTypeDef",
-    {
-        "RetentionPeriod": "RetentionPeriodTypeDef",
-        "ResourceType": ResourceTypeType,
-    },
-)
-_OptionalCreateRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateRuleRequestRequestTypeDef",
-    {
-        "Description": str,
-        "Tags": Sequence["TagTypeDef"],
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateRuleRequestRequestTypeDef(
-    _RequiredCreateRuleRequestRequestTypeDef, _OptionalCreateRuleRequestRequestTypeDef
-):
-    pass
-
-
-CreateRuleResponseTypeDef = TypedDict(
-    "CreateRuleResponseTypeDef",
-    {
-        "Identifier": str,
-        "RetentionPeriod": "RetentionPeriodTypeDef",
-        "Description": str,
-        "Tags": List["TagTypeDef"],
-        "ResourceType": ResourceTypeType,
-        "ResourceTags": List["ResourceTagTypeDef"],
-        "Status": RuleStatusType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteRuleRequestRequestTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     "DeleteRuleRequestRequestTypeDef",
-    {
-        "Identifier": str,
-    },
-)
-
-GetRuleRequestRequestTypeDef = TypedDict(
     "GetRuleRequestRequestTypeDef",
-    {
-        "Identifier": str,
-    },
-)
-
-GetRuleResponseTypeDef = TypedDict(
-    "GetRuleResponseTypeDef",
-    {
-        "Identifier": str,
-        "Description": str,
-        "ResourceType": ResourceTypeType,
-        "RetentionPeriod": "RetentionPeriodTypeDef",
-        "ResourceTags": List["ResourceTagTypeDef"],
-        "Status": RuleStatusType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListRulesRequestListRulesPaginateTypeDef = TypedDict(
-    "_RequiredListRulesRequestListRulesPaginateTypeDef",
-    {
-        "ResourceType": ResourceTypeType,
-    },
-)
-_OptionalListRulesRequestListRulesPaginateTypeDef = TypedDict(
-    "_OptionalListRulesRequestListRulesPaginateTypeDef",
-    {
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListRulesRequestListRulesPaginateTypeDef(
-    _RequiredListRulesRequestListRulesPaginateTypeDef,
-    _OptionalListRulesRequestListRulesPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListRulesRequestRequestTypeDef = TypedDict(
-    "_RequiredListRulesRequestRequestTypeDef",
-    {
-        "ResourceType": ResourceTypeType,
-    },
-)
-_OptionalListRulesRequestRequestTypeDef = TypedDict(
-    "_OptionalListRulesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
-    },
-    total=False,
-)
-
-
-class ListRulesRequestRequestTypeDef(
-    _RequiredListRulesRequestRequestTypeDef, _OptionalListRulesRequestRequestTypeDef
-):
-    pass
-
-
-ListRulesResponseTypeDef = TypedDict(
-    "ListRulesResponseTypeDef",
-    {
-        "Rules": List["RuleSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "ResourceArn": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": List["TagTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
+    "ListTagsForResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "ListRulesRequestRequestTypeDef",
+    "RuleSummaryTypeDef",
+    "UpdateRuleRequestRequestTypeDef",
+    "CreateRuleRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "CreateRuleResponseTypeDef",
+    "GetRuleResponseTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "UpdateRuleResponseTypeDef",
+    "ListRulesRequestListRulesPaginateTypeDef",
+    "ListRulesResponseTypeDef",
 )
 
 _RequiredResourceTagTypeDef = TypedDict(
@@ -213,17 +68,6 @@ class ResourceTagTypeDef(_RequiredResourceTagTypeDef, _OptionalResourceTagTypeDe
     pass
 
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 RetentionPeriodTypeDef = TypedDict(
     "RetentionPeriodTypeDef",
     {
@@ -232,24 +76,6 @@ RetentionPeriodTypeDef = TypedDict(
     },
 )
 
-RuleSummaryTypeDef = TypedDict(
-    "RuleSummaryTypeDef",
-    {
-        "Identifier": str,
-        "Description": str,
-        "RetentionPeriod": "RetentionPeriodTypeDef",
-    },
-    total=False,
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "ResourceArn": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-)
-
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -258,6 +84,48 @@ TagTypeDef = TypedDict(
     },
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
+DeleteRuleRequestRequestTypeDef = TypedDict(
+    "DeleteRuleRequestRequestTypeDef",
+    {
+        "Identifier": str,
+    },
+)
+
+GetRuleRequestRequestTypeDef = TypedDict(
+    "GetRuleRequestRequestTypeDef",
+    {
+        "Identifier": str,
+    },
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -266,6 +134,39 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredListRulesRequestRequestTypeDef = TypedDict(
+    "_RequiredListRulesRequestRequestTypeDef",
+    {
+        "ResourceType": ResourceTypeType,
+    },
+)
+_OptionalListRulesRequestRequestTypeDef = TypedDict(
+    "_OptionalListRulesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "ResourceTags": Sequence[ResourceTagTypeDef],
+    },
+    total=False,
+)
+
+
+class ListRulesRequestRequestTypeDef(
+    _RequiredListRulesRequestRequestTypeDef, _OptionalListRulesRequestRequestTypeDef
+):
+    pass
+
+
+RuleSummaryTypeDef = TypedDict(
+    "RuleSummaryTypeDef",
+    {
+        "Identifier": str,
+        "Description": str,
+        "RetentionPeriod": RetentionPeriodTypeDef,
+    },
+    total=False,
+)
+
 _RequiredUpdateRuleRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateRuleRequestRequestTypeDef",
     {
@@ -275,10 +176,10 @@ _RequiredUpdateRuleRequestRequestTypeDef = TypedDict(
 _OptionalUpdateRuleRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateRuleRequestRequestTypeDef",
     {
-        "RetentionPeriod": "RetentionPeriodTypeDef",
+        "RetentionPeriod": RetentionPeriodTypeDef,
         "Description": str,
         "ResourceType": ResourceTypeType,
-        "ResourceTags": Sequence["ResourceTagTypeDef"],
+        "ResourceTags": Sequence[ResourceTagTypeDef],
     },
     total=False,
 )
@@ -290,15 +191,114 @@ class UpdateRuleRequestRequestTypeDef(
     pass
 
 
+_RequiredCreateRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateRuleRequestRequestTypeDef",
+    {
+        "RetentionPeriod": RetentionPeriodTypeDef,
+        "ResourceType": ResourceTypeType,
+    },
+)
+_OptionalCreateRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateRuleRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": Sequence[TagTypeDef],
+        "ResourceTags": Sequence[ResourceTagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateRuleRequestRequestTypeDef(
+    _RequiredCreateRuleRequestRequestTypeDef, _OptionalCreateRuleRequestRequestTypeDef
+):
+    pass
+
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateRuleResponseTypeDef = TypedDict(
+    "CreateRuleResponseTypeDef",
+    {
+        "Identifier": str,
+        "RetentionPeriod": RetentionPeriodTypeDef,
+        "Description": str,
+        "Tags": List[TagTypeDef],
+        "ResourceType": ResourceTypeType,
+        "ResourceTags": List[ResourceTagTypeDef],
+        "Status": RuleStatusType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetRuleResponseTypeDef = TypedDict(
+    "GetRuleResponseTypeDef",
+    {
+        "Identifier": str,
+        "Description": str,
+        "ResourceType": ResourceTypeType,
+        "RetentionPeriod": RetentionPeriodTypeDef,
+        "ResourceTags": List[ResourceTagTypeDef],
+        "Status": RuleStatusType,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateRuleResponseTypeDef = TypedDict(
     "UpdateRuleResponseTypeDef",
     {
         "Identifier": str,
-        "RetentionPeriod": "RetentionPeriodTypeDef",
+        "RetentionPeriod": RetentionPeriodTypeDef,
         "Description": str,
         "ResourceType": ResourceTypeType,
-        "ResourceTags": List["ResourceTagTypeDef"],
+        "ResourceTags": List[ResourceTagTypeDef],
         "Status": RuleStatusType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredListRulesRequestListRulesPaginateTypeDef = TypedDict(
+    "_RequiredListRulesRequestListRulesPaginateTypeDef",
+    {
+        "ResourceType": ResourceTypeType,
+    },
+)
+_OptionalListRulesRequestListRulesPaginateTypeDef = TypedDict(
+    "_OptionalListRulesRequestListRulesPaginateTypeDef",
+    {
+        "ResourceTags": Sequence[ResourceTagTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListRulesRequestListRulesPaginateTypeDef(
+    _RequiredListRulesRequestListRulesPaginateTypeDef,
+    _OptionalListRulesRequestListRulesPaginateTypeDef,
+):
+    pass
+
+
+ListRulesResponseTypeDef = TypedDict(
+    "ListRulesResponseTypeDef",
+    {
+        "Rules": List[RuleSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
